Class: Kiqr::Commands
- Inherits:
-
Thor
- Object
- Thor
- Kiqr::Commands
- Includes:
- Thor::Actions
- Defined in:
- lib/kiqr/commands.rb
Class Method Summary collapse
-
.exit_on_failure? ⇒ Boolean
This is a Thor class method that will be called when an error occurs.
Instance Method Summary collapse
Class Method Details
.exit_on_failure? ⇒ Boolean
This is a Thor class method that will be called when an error occurs.
9 10 11 |
# File 'lib/kiqr/commands.rb', line 9 def self.exit_on_failure? true end |
Instance Method Details
#config ⇒ Object
14 15 16 17 |
# File 'lib/kiqr/commands.rb', line 14 def config say "KIQR Configuration:\n\n" ap Kiqr::Config.config.stringify_keys, indent: -2 end |
#update ⇒ Object
23 24 25 26 |
# File 'lib/kiqr/commands.rb', line 23 def update require "generators/kiqr/update/update_generator" Kiqr::UpdateGenerator.start end |
#version ⇒ Object
29 30 31 |
# File 'lib/kiqr/commands.rb', line 29 def version say Gem.loaded_specs["kiqr"].version end |