Module: Kiqr::Controllers::UrlHelpers
- Defined in:
- lib/kiqr/controllers/url_helpers.rb
Instance Method Summary collapse
-
#current_base_path?(path) ⇒ Boolean
Check if the current path matches the base path provided, ignoring query parameters.
-
#invitation_token_url(token) ⇒ Object
Generate a URL for the invitation token.
Instance Method Details
#current_base_path?(path) ⇒ Boolean
Check if the current path matches the base path provided, ignoring query parameters.
10 11 12 |
# File 'lib/kiqr/controllers/url_helpers.rb', line 10 def current_base_path?(path) request.path.start_with?(path.split("?").first) end |
#invitation_token_url(token) ⇒ Object
Generate a URL for the invitation token.
5 6 7 |
# File 'lib/kiqr/controllers/url_helpers.rb', line 5 def invitation_token_url(token) user_invitation_url(token: token, account_id: nil) end |