Module: Kiqr::Themes::Irelia
- Defined in:
- lib/kiqr/themes/irelia.rb,
lib/kiqr/themes/irelia/config.rb,
lib/generators/kiqr/themes/irelia/install_generator.rb
Defined Under Namespace
Classes: Config, InstallGenerator
Class Method Summary collapse
-
.config ⇒ Object
Class method to access the Irelia theme configuration This method uses memoization to store the config instance.
Class Method Details
.config ⇒ Object
Class method to access the Irelia theme configuration This method uses memoization to store the config instance
12 13 14 15 16 |
# File 'lib/kiqr/themes/irelia.rb', line 12 def self.config # If @config is nil, initialize it with Kiqr::Themes::Irelia::Config # Otherwise, return the existing @config @config ||= Kiqr::Themes::Irelia::Config end |