Class: PublicController
- Inherits:
-
ApplicationController
- Object
- ActionController::Base
- ApplicationController
- PublicController
- Defined in:
- lib/generators/kiqr/install/templates/rails/app/controllers/public_controller.rb
Instance Method Summary collapse
-
#landing_page ⇒ Object
> Landing page This method is used to render the landing page of the application Edit the view file: app/views/public/landing_page.html.erb.
Methods inherited from ApplicationController
Instance Method Details
#landing_page ⇒ Object
> Landing page
This method is used to render the landing page of the application Edit the view file: app/views/public/landing_page.html.erb
9 10 |
# File 'lib/generators/kiqr/install/templates/rails/app/controllers/public_controller.rb', line 9 def landing_page end |