Class: ApplicationController
- Inherits:
-
ActionController::Base
- Object
- ActionController::Base
- ApplicationController
- Defined in:
- lib/generators/kiqr/install/templates/rails/app/controllers/application_controller.rb
Direct Known Subclasses
Instance Method Summary collapse
-
#default_url_options ⇒ Object
Automatically include account_id in all URL options if it is already present in the params.
Instance Method Details
#default_url_options ⇒ Object
Automatically include account_id in all URL options if it is already present in the params. This is used to ensure that all routes are scoped to the current team. Personal account routes are not affected.
18 19 20 |
# File 'lib/generators/kiqr/install/templates/rails/app/controllers/application_controller.rb', line 18 def { account_id: params[:account_id] } end |